@@ -1,9 +1,5 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: after.c 138 2006-09-22 22:12:03Z mikes@u.washington.edu $";
-#endif
-
 /* ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006-2007 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -124,7 +120,7 @@ stop_after(int join)
 	}
     }
 
-    /* not literally true uless "join" set */
+    /* not literally true unless "join" set */
     after_active = 0;
 
 #else	/* !(defined(HAVE_PTHREAD) && defined(HAVE_NANOSLEEP)) */
