@@ -1,10 +1,6 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: help.c 1032 2008-04-11 00:30:04Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
- * Copyright 2013-2021 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -36,6 +32,7 @@ static char rcsid[] = "$Id: help.c 1032 2008-04-11 00:30:04Z hubert@u.washington
 #include "../pith/detoken.h"
 #include "../pith/list.h"
 #include "../pith/margin.h"
+#include "../pith/busy.h"
 
 
 typedef struct _help_scroll {
@@ -135,14 +132,17 @@ helper_internal(HelpType text, char *frag, char *title, int flags)
     is_external = 0;
 
     if(shown_text && *shown_text && !struncmp(*shown_text, "x-alpine-http:", 14)){
-	int status;
-	HTTPSTREAM *stream = http_open(*shown_text + 14);
-	if(stream) help_text = http_get(stream, NULL);
-	status = stream->status ? stream->status->code : -1;
+	int status, we_cancel = 0;
+
+	we_cancel = busy_cue(_("Retrieving help text"), NULL, 1);
+	HTTPSTREAM *stream = http_open((unsigned char *) (*shown_text + 14));
+	if(stream) help_text = (char *) http_get(stream, NULL);
+	status = stream && stream->status ? stream->status->code : -1;
 	if(stream) http_close(stream);
 	if(status != HTTP_OK){
 	    shown_text = NO_HELP;
 	    if(help_text) fs_give((void **) &help_text);
+	    q_status_message(SM_ORDER, 0, 2, _("Failed to retrieve help text. Try again later."));
 	    return MC_FINISH;
 	}
 	else{
@@ -165,7 +165,8 @@ helper_internal(HelpType text, char *frag, char *title, int flags)
 		*rv = NULL;
 	    }
 	}
-
+	if(we_cancel)
+	   cancel_busy_cue(-1);
     }
 
     if(F_ON(F_BLANK_KEYMENU,ps_global)){
@@ -372,7 +373,7 @@ helper_internal(HelpType text, char *frag, char *title, int flags)
     while(cmd == MC_RESIZE);
 
     if(external_text != NULL){
-      for(rv = external_text; *rv != NULL; *rv++)
+      for(rv = external_text; *rv != NULL; rv++)
 	fs_give((void **) &*rv);
       fs_give((void **) external_text);
     }
