@@ -2,7 +2,7 @@
  * $Id: keymenu.h 1074 2008-06-04 00:08:43Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2013-2021 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -220,6 +220,19 @@ struct key_menu {
 #define MC_XSADD	807
 #define MC_XSDELETE	808
 #define MC_XSHELP	809
+#define MC_DELTHREAD	810
+#define MC_UNDTHREAD	811
+#define MC_SELTHREAD	812
+#define MC_SSUTHREAD	813
+#define MC_DSUTHREAD	814
+#define MC_USUTHREAD	815
+#define MC_SORTHREAD	816
+#define MC_NEXTHREAD	817
+#define MC_KOLAPSE	818
+#define MC_EXPTHREAD	819
+#define MC_PRETHREAD	820
+#define MC_CTHREAD	821
+#define MC_OTHREAD	822
 
 /* Commands for S/MIME screens */
 #define MC_TRUST	900
@@ -692,7 +705,7 @@ int	    menu_clear_binding(struct key_menu *, UCS);
 int	    menu_binding_index(struct key_menu *, int);
 void	    mark_keymenu_dirty(void);
 void	    blank_keymenu(int, int);
-void	    draw_keymenu(struct key_menu *, bitmap_t, int, int, int, OtherMenu);
+void	    draw_keymenu(struct key_menu *, unsigned char *, int, int, int, OtherMenu);
 void	    redraw_keymenu(void);
 void	    clearfooter(struct pine *);
 
