@@ -1,11 +1,7 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: debuging.c 900 2008-01-05 01:13:26Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2021 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -138,6 +134,7 @@ init_debug(void)
 
     if(debugfile != NULL){
 	char rev[128];
+	extern char plevstamp[];
 	time_t now = time((time_t *)0);
 	if(ps_global->debug_flush)
 	  setvbuf(debugfile, (char *)NULL, _IOLBF, BUFSIZ);
@@ -160,6 +157,8 @@ init_debug(void)
 	       get_alpine_revision_string(rev, sizeof(rev)),
 	       ctime(&now)));
 
+	dprint((0, "This version uses all.patch:\n%s\n\n", plevstamp));
+
 	dprint((0, "Starting after the reading_pinerc calls, the data in this file should\nbe encoded as UTF-8. Before that it will be in the user's native charset.\n"));
 	if(dfile && (debug > DEFAULT_DEBUG ||
 		     ps_global->debug_imap > 0 ||
