@@ -1,11 +1,7 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: termin.unx.c 1025 2008-04-08 22:59:38Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -111,6 +107,8 @@ open_mailer for details.
 int
 init_tty_driver(struct pine *ps)
 {
+   if(ps->send_immediately)
+     return 0;
 #ifdef	MOUSE
     if(F_ON(F_ENABLE_MOUSE, ps_global))
       init_mouse();
@@ -683,6 +681,9 @@ a lot of at UW
 void
 init_keyboard(int use_fkeys)
 {
+    if (ps_global->send_immediately)
+	return;
+
     if(use_fkeys && (!strucmp(term_name,"vt102")
 		     || !strucmp(term_name,"vt100")))
       printf("\033\133\071\071\150");
@@ -700,6 +701,9 @@ init_keyboard(int use_fkeys)
 void
 end_keyboard(int use_fkeys)
 {
+    if(ps_global->send_immediately)
+	return;
+
     if(use_fkeys && (!strcmp(term_name, "vt102")
 		     || !strcmp(term_name, "vt100"))){
 	printf("\033\133\071\071\154");
