@@ -1,10 +1,6 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: smime.c 1074 2008-06-04 00:08:43Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -87,7 +83,8 @@ smime_get_passphrase(void)
             _("Enter passphrase for <%s>: "), (ps_global->smime && ps_global->smime->passphrase_emailaddr) ? ps_global->smime->passphrase_emailaddr[0] : "unknown");
 
     do {
-        flags = OE_PASSWD | OE_DISALLOW_HELP;
+        flags = F_ON(F_QUELL_ASTERISKS, ps_global) ? OE_PASSWD_NOAST : OE_PASSWD;
+        flags |= OE_DISALLOW_HELP;
 	((char *) ps_global->smime->passphrase)[0] = '\0';
         rc =  optionally_enter((char *) ps_global->smime->passphrase,
 			       -FOOTER_ROWS(ps_global), 0,
@@ -478,7 +475,7 @@ output_cert_info(X509 *cert, gf_io_t pc)
     gf_puts(NEWLINE, pc);
     
     if((chain = get_chain_for_cert(cert, &error, &len)) != NULL){
-       X509 *x;
+       X509 *x = NULL;
        X509_NAME_ENTRY *e;
        int i, offset = 2;
        char space[256];
@@ -1287,24 +1284,31 @@ manage_certs_tool(struct pine *ps, int cmd, CONF_S **cl, unsigned flags)
 		     && can_access(pathdir, ACCESS_EXISTS) != 0
 	             && our_mkpath(pathdir, 0700) == 0)){
 	        pc = ALPINE_self_signed_certificate(NULL, 0, pathdir, MASTERNAME);
-		snprintf(filename, sizeof(filename), "%s/%s.key", 
-					pathdir, MASTERNAME);
-		filename[sizeof(filename)-1] = '\0';
-		rv = import_certificate(ctype, pc, filename);
-		if(rv == 1){
-		  ps->keyemptypwd = 0;
-		  if(our_stat(pathdir, &sbuf) == 0){
-		    if(unlink(filename) < 0)
-		      q_status_message1(SM_ORDER, 0, 2, 
-			_("Could not remove private key %s.key"), MASTERNAME);
-		    filename[strlen(filename)-4] = '\0';
-		    strcat(filename, ".crt");
-		    if(unlink(filename) < 0)
-		      q_status_message1(SM_ORDER, 0, 2, 
-			_("Could not remove public certificate %s.crt"), MASTERNAME);
-		    if(rmdir(pathdir) < 0)
-		      q_status_message1(SM_ORDER, 0, 2, 
-		      _("Could not remove temporary directory %s"), pathdir);
+		if(strlen(pathdir) + strlen(MASTERNAME) + 5 + 1 > sizeof(filename)){
+		      q_status_message(SM_ORDER, 0, 2, 
+			_("pathdir for key too long"));
+		}
+		else{
+		  snprintf(filename, sizeof(filename), "%.*s/%.*s.key",
+				(int) strlen(pathdir), pathdir,
+				(int) (sizeof(filename) - strlen(MASTERNAME) - 5 - 1), MASTERNAME);
+		  filename[sizeof(filename)-1] = '\0';
+		  rv = import_certificate(ctype, pc, filename);
+		  if(rv == 1){
+		    ps->keyemptypwd = 0;
+		    if(our_stat(pathdir, &sbuf) == 0){
+		      if(unlink(filename) < 0)
+		        q_status_message1(SM_ORDER, 0, 2, 
+			  _("Could not remove private key %s.key"), MASTERNAME);
+		      filename[strlen(filename)-4] = '\0';
+		      strcat(filename, ".crt");
+		      if(unlink(filename) < 0)
+		        q_status_message1(SM_ORDER, 0, 2, 
+			  _("Could not remove public certificate %s.crt"), MASTERNAME);
+		      if(rmdir(pathdir) < 0)
+		        q_status_message1(SM_ORDER, 0, 2, 
+		        _("Could not remove temporary directory %s"), pathdir);
+		    }
 		  }
 		}
 	      }
@@ -1511,12 +1515,9 @@ void
 smime_manage_password_file_certs_init(struct pine *ps, CONF_S **ctmp, CONF_S **first_line, int fline, int *state)
 {
     char     tmp[200];
-    char    *ext;
     CertList *cl;
     int	  i;
     void  *pwdcert = NULL;	/* this is our current password file */
-    X509_LOOKUP *lookup = NULL;
-    X509_STORE  *store  = NULL;
     char filename[MAXPATH+1];
     BIO *in = NULL;
     EVP_PKEY *key = NULL;
@@ -1638,14 +1639,13 @@ void
 smime_manage_certs_init(struct pine *ps, CONF_S **ctmp, CONF_S **first_line, WhichCerts ctype, int fline)
 {
     char            tmp[200];
-    char	   *ext;
     CertList	   *data;
     int		    i;
 
     smime_init();
 
     data = DATACERT(ctype);
-    ext  = EXTCERT(ctype);
+//    ext  = EXTCERT(ctype);
 
     if(data == NULL || RENEWCERT(data))
       renew_cert_data(&data, ctype);
@@ -1710,8 +1710,6 @@ smime_manage_certs_init(struct pine *ps, CONF_S **ctmp, CONF_S **first_line, Whi
 
       for(cl = data, i = 0; cl; cl = cl->next)
 	 if(cl->name){
-	    char *s, *t;
-
 	    new_confline(ctmp);
 	    (*ctmp)->d.s.ctype  = ctype;
 	    (*ctmp)->d.s.deleted = get_cert_deleted(ctype, i);
