@@ -1,11 +1,7 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: takeaddr.c 1012 2008-03-26 00:44:22Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -1130,7 +1126,7 @@ takeaddr_screen(struct pine *ps, TA_S *ta_list, int how_many_selected,
     TA_SCREEN_S   screen;
     Pos           cursor_pos;
     char         *utf8str;
-    struct key_menu *km;
+    struct key_menu *km = NULL;
 
     dprint((2, "- takeaddr_screen -\n"));
 
@@ -1720,7 +1716,7 @@ update_takeaddr_screen(struct pine *ps, TA_S *current, TA_SCREEN_S *screen, Pos
           *ctmp;
     int    longest, i, j;
     char   buf1[6*MAX_SCREEN_COLS + 30];
-    char   buf2[6*MAX_SCREEN_COLS + 30];
+    char   buf2[6*MAX_SCREEN_COLS + 30 + 10];
     char  *p, *q;
     int screen_width = ps->ttyo->screen_cols;
     Pos    cpos;
@@ -2069,7 +2065,7 @@ take_without_edit(TA_S *ta_list, int num_in_list, int command_line, TA_STATE_S *
 #define OURTMPBUFLEN 200
     PerAddrBook   *pab_dst;
     SAVE_STATE_S   state;  /* For saving state of addrbooks temporarily */
-    int            rc, total_to_copy;
+    int            rc, total_to_copy = 0;
     int		   how_many_dups = 0, how_many_to_copy = 0, skip_dups = 0;
     int		   ret = 0;
     int		   err = 0, need_write = 0, we_cancel = 0;
