@@ -1,7 +1,7 @@
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2021 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -33,48 +33,24 @@ typedef struct xoauh2_info_val_s {
 
 /* the order here must match the order in XTYPES above */
 XOAUTH2_INFO_VAL_S x_default[] = {
-   {NULL, 		"/NAME="},
-   {"Client-Id",	"/ID="},
-   {"Client-Secret",	"/SECRET="},
-   {"Tenant",		"/TENANT="},
-   {"Username",		"/USER="},
-   {"Auth Flow",	"/Flow="},
-   {NULL, 		NULL}
+   {NULL, 			XNAME},
+   {XOAUTH2_CLIENT_ID,		XID},
+   {XOAUTH2_CLIENT_SECRET,	XSECRET},
+   {XOAUTH2_TENANT,		XTENANT},
+   {XOAUTH2_USERS,		XUSER},
+   {XOAUTH2_FLOW,		XFLOW},
+   {NULL, 			NULL}
 };
 
-#define XNAME	x_default[Xname].pinerc_name
-#define XID	x_default[Xid].pinerc_name
-#define XSECRET	x_default[Xsecret].pinerc_name
-#define XTENANT	x_default[Xtenant].pinerc_name
-#define XUSER	x_default[Xuser].pinerc_name
-#define XFLOW	x_default[XFlow].pinerc_name
-
-#define XOAUTH2_CLIENT_ID	x_default[Xid].screen_name
-#define XOAUTH2_CLIENT_SECRET	x_default[Xsecret].screen_name
-#define XOAUTH2_TENANT		x_default[Xtenant].screen_name
-#define XOAUTH2_USERS		x_default[Xuser].screen_name
-#define XOAUTH2_FLOW		x_default[XFlow].screen_name
-
 char *list_to_array(char **);
 char **array_to_list(char *);
 void write_xoauth_configuration(struct variable  *, struct variable **, EditWhich);
 char **xoauth2_conf_dedup_and_merge(char ***);
-int  same_xoauth2_info(XOAUTH2_INFO_S, XOAUTH2_INFO_S);
 XOAUTH2_INFO_S *xoauth_info_choice(XOAUTH2_INFO_S **, char *);
 int xoauth2_info_tool(struct pine *, int, CONF_S **, unsigned int);
-
-int
-same_xoauth2_info(XOAUTH2_INFO_S x, XOAUTH2_INFO_S y)
-{
-   int rv = 0;
-   if(x.name && y.name && !strcmp((char *) x.name, (char *) y.name)
-	&& x.client_id && y.client_id && !strcmp(x.client_id, y.client_id)
-	&& ((!x.client_secret && !y.client_secret)
-		|| (x.client_secret && y.client_secret && !strcmp(x.client_secret, y.client_secret)))
-	&& ((!x.tenant && !y.tenant) || (x.tenant && y.tenant && !strcmp(x.tenant, y.tenant))))
-	rv = 1;
-   return rv;
-}
+char *xoauth2_extra_text(XOAUTH2_INFO_S **, int);
+XOAUTH2_INFO_S **xoauth2_configured_servers(void);
+XOAUTH2_INFO_S **parse_xoauth2_info_list(char **lval, int *totalp);
 
 char *
 list_to_array(char **list)
@@ -162,24 +138,93 @@ xoauth2_info_tool(struct pine *ps, int cmd, CONF_S **cl, unsigned int flags)
    return rv;
 }
 
+char *
+xoauth2_extra_text(XOAUTH2_INFO_S **xinfo, int i)
+{
+  int methodcount;
+  int j;
+  XOAUTH2_INFO_S *x;
+  char *rv = NULL;
+
+  if(xinfo == NULL)
+     return NULL;
+
+  for(j = 0; xinfo[j] != NULL; j++);
+  if(i < 0 || i >= j) return NULL;
+
+  x = xinfo[i];
+  if(x->flow){
+    for(methodcount = 1, j = 0; xinfo[j] != NULL; j++)
+      if(j != i && xinfo[j]->flow && !strucmp(xinfo[j]->flow, x->flow))
+	methodcount++;
+    if(methodcount == 1) return cpystr(x->flow);
+  }
+
+  /* we either do not have flow, or have more than one flow, use user */
+  if(x->users){
+      char **lval = array_to_list(xinfo[i]->users);
+      if(lval && lval[0]){	/* use the first one */
+	rv = cpystr(lval[0]);
+	free_list_array(&lval);
+      }
+  }
+
+  if(rv == NULL) rv = cpystr(_("client-id unused"));
+  return rv;
+}
+
 XOAUTH2_INFO_S *
 xoauth_info_choice(XOAUTH2_INFO_S **xinfo, char *user)
 {
    int i, n, rv;
+   char *extra;
+
+   dprint((9, "xoauth_info_choice()"));
+
+   for(i = 0; xinfo && xinfo[i]; i++);
+   if(i == 0) return NULL;
+
+   if(strucmp((char *) xinfo[0]->name, (char *) GMAIL_NAME) == 0){
+      for(i = 0; xinfo && xinfo[i] && strcmp(xinfo[i]->client_id, (char *) GMAIL_ID) != 0; i++);
+      if(!xinfo || xinfo[i] != NULL){
+	int j, offset = 0;
+	XOAUTH2_INFO_S *x;
+
+	for(j = 0; xinfo[j] != NULL; j++){
+	   if(j == i){
+	      offset++;
+	      continue;
+	   }
+	   x = xinfo[j] ? copy_xoauth2_info(xinfo[j]) : NULL;
+	   free_xoauth2_info(&xinfo[j - offset]);
+	   xinfo[j - offset] = x;
+	}
+	xinfo[j - offset] = NULL;
+	for(i = 0; xinfo && xinfo[i]; i++);
+      }
+   }
+
+   if(i == 1) return copy_xoauth2_info(xinfo[0]);
+
    if(!ps_global->ttyo){
 	char *s;
 	char prompt[1024];
 	char reply[1024];
 	int sel;
 	for(i = n = 0; xinfo[i] != NULL; i++)
-	   n += strlen(xinfo[i]->client_id) + 5;	/* number, parenthesis, space */
+	   n += strlen(xinfo[i]->client_id) + strlen(xinfo[i]->flow ? xinfo[i]->flow : "")
+		+ strlen(xinfo[i]->users ? xinfo[i]->users : "") + 8;	/* number, parenthesis, space */
 	n += strlen((char *) xinfo[0]->name) + strlen(user);
-	n += 1024;	/* large enough to display to lines of 80 characters in UTF-8 */
+	n += 1024;	/* large enough to display lines of 80 characters in UTF-8 */
 	s = fs_get(n*sizeof(char));
 	sprintf(s, _("Alpine cannot determine which client-id to use for the username <%s> for your %s account. "), user, xinfo[0]->name);
 	sprintf(s + strlen(s), _("Please select the client-id to use from the following list.\n\n"));
-	for(i = 0; xinfo[i]; i++)
-	   sprintf(s + strlen(s), " %d) %.70s\n", i+1, xinfo[i]->client_id);
+	for(i = 0; xinfo[i]; i++){
+	   extra = xoauth2_extra_text(xinfo, i);
+	   sprintf(s + strlen(s), " %d) %.70s%s%s\n", i+1, xinfo[i]->client_id,
+				extra ? " - " : "", extra ? extra : "");
+	   if(extra) fs_give((void **) &extra);
+	}
 	sprintf(s + strlen(s), "%s", "\n\n");
 
 	display_init_err(s, 0);
@@ -192,7 +237,7 @@ xoauth_info_choice(XOAUTH2_INFO_S **xinfo, char *user)
 	   sel = atoi(reply) - 1;
 	   rv = (sel >= 0 && sel < i) ? 0 : -1;
 	} while (rv != 0);
-	return copy_xoauth2_info(xinfo[rv]);
+	return copy_xoauth2_info(xinfo[sel]);
    }
    else{
       CONF_S  *ctmp = NULL, *first_line = NULL;
@@ -200,7 +245,6 @@ xoauth_info_choice(XOAUTH2_INFO_S **xinfo, char *user)
       OPT_SCREEN_S   screen;
       char tmp[1024];
 
-      dprint((9, "xoauth2 select client-id screen"));
       ps_global->next_screen = SCREEN_FUN_NULL;
 
       memset(&screen, 0, sizeof(screen));
@@ -234,15 +278,22 @@ xoauth_info_choice(XOAUTH2_INFO_S **xinfo, char *user)
       ctmp->flags |= CF_NOSELECT;
       ctmp->value = cpystr(tmp);
 
-      new_confline(&ctmp);
-      ctmp->flags |= CF_NOSELECT | CF_B_LINE;
-
       for(i = 0; xinfo[i] != NULL; i++){
+        new_confline(&ctmp);
+        ctmp->flags |= CF_NOSELECT | CF_B_LINE;
+
+	if((extra = xoauth2_extra_text(xinfo, i)) != NULL){
+           new_confline(&ctmp);
+           ctmp->flags |= CF_NOSELECT;
+           ctmp->value = cpystr(extra);
+	   ctmp->valoffset = 4;
+	}
+
 	new_confline(&ctmp);
         if(!first_line)
           first_line = ctmp;
 
-        ctmp->value        = cpystr(xinfo[i]->client_id);
+	ctmp->value = cpystr(xinfo[i]->client_id);
         ctmp->d.x.selected = &x_sel;
         ctmp->d.x.pat      = copy_xoauth2_info(xinfo[i]);
         ctmp->keymenu      = &xoauth2_id_select_km;
@@ -250,7 +301,8 @@ xoauth_info_choice(XOAUTH2_INFO_S **xinfo, char *user)
         ctmp->help_title   = NULL;
         ctmp->tool         = xoauth2_info_tool;
         ctmp->flags        = CF_STARTITEM;
-        ctmp->valoffset    = 4;
+        ctmp->valoffset    = 4 + (extra ? 3 : 0);
+	if(extra) fs_give((void **) &extra);
       }
      (void)conf_scroll_screen(ps_global, &screen, first_line, _("SELECT CLIENT_ID"),
                              _("xoauth2"), 0, NULL);
@@ -259,45 +311,89 @@ xoauth_info_choice(XOAUTH2_INFO_S **xinfo, char *user)
    return NULL;
 }
 
+XOAUTH2_INFO_S **
+parse_xoauth2_info_list(char **lval, int *totalp)
+{
+   int i, total;
+   XOAUTH2_INFO_S **rv = NULL;
+
+   for(total = 0; lval && lval[total]; total++);
+   if(total){
+      rv = fs_get((total + 1)*sizeof(XOAUTH2_INFO_S *));
+      for(i = 0; i < total; i++)
+	rv[i] = xoauth_parse_client_info(lval[i]);
+      rv[i] = NULL;
+   }
+   *totalp = total;
+   return rv;
+}
+
+
+XOAUTH2_INFO_S **
+xoauth2_configured_servers(void)
+{
+  XOAUTH2_INFO_S **cv, **muv, **rv = NULL;
+  int cvt, muvt, rvt, i, j, total = 0;
+
+  cv = parse_xoauth2_info_list(ps_global->vars[V_XOAUTH2_INFO].current_val.l, &cvt);
+  muv = parse_xoauth2_info_list(ps_global->vars[V_XOAUTH2_INFO].main_user_val.l, &muvt);
+
+  rvt = cvt + muvt;
+  if(rvt){
+     rv = fs_get((rvt + 1)*sizeof(XOAUTH2_INFO_S *));
+     memset((void *) rv, 0, (rvt + 1)*sizeof(XOAUTH2_INFO_S *));
+
+     for(i = 0; cv && cv[i]; i++){
+	for(j = 0; rv[j] && !same_xoauth2_info(*cv[i], *rv[j]); j++);
+	if(!rv[j]) rv[total++] = copy_xoauth2_info(cv[i]);
+     }
+
+     for(i = 0; muv && muv[i]; i++){
+	for(j = 0; rv[j] && !same_xoauth2_info(*muv[i], *rv[j]); j++);
+	if(!rv[j]) rv[total++] = copy_xoauth2_info(muv[i]);
+     }
+  }
+  return rv;
+}
+
 /* Get the client-id, etc. for server "name" associated to user "user" */
 XOAUTH2_INFO_S *
 oauth2_get_client_info(unsigned char *name, char *user)
 {
   int i, j, matches, len;
-  char **lval;
-  XOAUTH2_INFO_S *x, **xinfo;
+  XOAUTH2_INFO_S *x, **xinfo, **lval;
 
   if(name == NULL || *name == '\0' || user == NULL || *user == '\0')
     return NULL;
 
   matches = 0;
   /* first count how many servers  */
-  lval = ps_global->vars[V_XOAUTH2_INFO].current_val.l;
+  lval = xoauth2_configured_servers();
   for(i = 0; lval && lval[i]; i++){
-     x = xoauth_parse_client_info(lval[i]);
+     x = lval[i];
      if(x && x->name && name && !strcmp((char *) x->name, (char *) name))
 	matches++;
-     free_xoauth2_info(&x);
   }
 
   /* if nothing, use the default value */
   for(i = 0; xoauth_default[i].name != NULL && strcmp((char *) xoauth_default[i].name, (char *) name); i++);
   if(xoauth_default[i].name) matches++;
 
-  if(matches == 0) return NULL;
-  if(matches == 1) return copy_xoauth2_info(&xoauth_default[i]);
+  if(matches <= 1){
+     free_xoauth2_info_list(&lval);
+     return matches == 1 ? copy_xoauth2_info(&xoauth_default[i]) : NULL;
+  }
 
   /* more than one match, see if it is a duplicate client-id entry */
   xinfo = fs_get((matches + 1)*sizeof(XOAUTH2_INFO_S *));
   memset((void *)xinfo, 0, (matches + 1)*sizeof(XOAUTH2_INFO_S *));
   matches = 0;	/* restart the recount, it might go lower! */
   for(i = 0; lval && lval[i]; i++){
-     x = xoauth_parse_client_info(lval[i]);
+     x = lval[i];
      if(x && x->name && name && !strcmp((char *) x->name, (char *) name)){
 	for(j = 0; xinfo && xinfo[j] && !same_xoauth2_info(*x, *xinfo[j]); j++);
 	if(!xinfo[j]) xinfo[matches++] = copy_xoauth2_info(x);
      }
-     free_xoauth2_info(&x);
   }
   for(i = 0; xoauth_default[i].name != NULL && strcmp((char *) xoauth_default[i].name, (char *) name); i++);
   for(j = 0; xinfo && xinfo[j] && !same_xoauth2_info(xoauth_default[i], *xinfo[j]); j++);
@@ -306,58 +402,57 @@ oauth2_get_client_info(unsigned char *name, char *user)
   /* if after removing the duplicate entries, we only have one, use it */
   if(matches == 1){
      x = copy_xoauth2_info(xinfo[0]);
-     for(i = 0; xinfo[i] != NULL; i++)
-        free_xoauth2_info(&xinfo[i]);
-     fs_give((void **) &xinfo);
+     free_xoauth2_info_list(&lval);
+     free_xoauth2_info_list(&xinfo);
      return x;
   }
 
+  x = NULL;	/* reset x to null so it will not be double freed */
   /* we have more than one match, now check if any of them matches the given user */
   matches = 0;
   for(i = 0; xinfo && xinfo[i]; i++){
-      lval = array_to_list(xinfo[i]->users);
-      for(j = 0; lval && lval[j] && strucmp(lval[j], user); j++);
-      if(lval && lval[j]){
+      char **alval = array_to_list(xinfo[i]->users);
+      for(j = 0; alval && alval[j] && strucmp(alval[j], user); j++);
+      if(alval && alval[j]){
 	 matches++;
 	 free_xoauth2_info(&x);
 	 x = copy_xoauth2_info(xinfo[i]);
       }
-      if(lval) free_list_array(&lval);
+      if(alval) free_list_array(&alval);
   }
 
   /* only one server matches the username */
   if(matches == 1){
-     for(i = 0; xinfo[i] != NULL; i++)
-         free_xoauth2_info(&xinfo[i]);
-     fs_give((void **) &xinfo);
+     free_xoauth2_info_list(&xinfo);
+     free_xoauth2_info_list(&lval);
      return x;
   }
 
   free_xoauth2_info(&x);
+
   /* We either have no matches, or have more than one match!
    * in either case, let the user pick what they want */
    x = xoauth_info_choice(xinfo, user);
-   for(i = 0; xinfo[i] != NULL; i++)
-      free_xoauth2_info(&xinfo[i]);
-   fs_give((void **) &xinfo);
+   free_xoauth2_info_list(&xinfo);
+   free_xoauth2_info_list(&lval);
 
    /* Once the user chose a client-id, save it so we do not ask again */
    if(x != NULL){
       int n = x->users ? strlen(x->users) + 1 : 0;
-      char ***alval;
+      char ***alval, **lvalp;
 
       fs_resize((void **) &x->users, (n + strlen(user) + 1)*sizeof(char));
       x->users[n > 0 ? n - 1 : 0] = '\0';
       if(n > 0) strcat(x->users, ",");
       strcat(x->users, user);
       alval = ALVAL(&ps_global->vars[V_XOAUTH2_INFO], Main);
-      lval = *alval;
+      lvalp = *alval;
 
-      for(n = 0; lval && lval[n]; n++);
-      fs_resize((void **) &lval, (n+2)*sizeof(char *));
-      lval[n] = xoauth_config_line(x);
-      lval[n+1] = NULL;
-      *alval = xoauth2_conf_dedup_and_merge(&lval);
+      for(n = 0; lvalp && lvalp[n]; n++);
+      fs_resize((void **) &lvalp, (n+2)*sizeof(char *));
+      lvalp[n] = xoauth_config_line(x);
+      lvalp[n+1] = NULL;
+      *alval = xoauth2_conf_dedup_and_merge(&lvalp);
       set_current_val(&ps_global->vars[V_XOAUTH2_INFO], FALSE, FALSE);
       write_pinerc(ps_global, Main, WRP_NONE);
    }
