@@ -1,5 +1,5 @@
 /* ========================================================================
- * Copyright 2018 - 2020 Eduardo Chappa
+ * Copyright 2018-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -107,6 +107,9 @@ long auth_oauth2_client (authchallenge_t challenger,authrespond_t responder, cha
 
     oauth2.param[OA2_State].value = oauth2_generate_state();
 
+    oauth2_code_challenge(&oauth2);
+
+    oauth2_login_hint(&oauth2, user);
     /* 
      * If we did not get an access token, try to get one through 
      * our internal functions
@@ -168,11 +171,6 @@ long auth_oauth2_client (authchallenge_t challenger,authrespond_t responder, cha
 	*trial = 65535; 	/* don't retry if bad protocol */
     }
   }
-  if(oauth2.param[OA2_Id].value) fs_give((void **) &oauth2.param[OA2_Id].value);
-  if(oauth2.param[OA2_Secret].value) fs_give((void **) &oauth2.param[OA2_Secret].value);
-  if(oauth2.param[OA2_Tenant].value) fs_give((void **) &oauth2.param[OA2_Tenant].value);
-  if(oauth2.param[OA2_State].value) fs_give((void **) &oauth2.param[OA2_State].value);
-  if(oauth2.param[OA2_RefreshToken].value) fs_give((void **) &oauth2.param[OA2_RefreshToken].value);
-  if(oauth2.access_token) fs_give((void **) &oauth2.access_token);
+  oauth2_free_extra_values(oauth2);
   return ret;
 }
