@@ -1,5 +1,5 @@
 /* ========================================================================
- * Copyright 2019 - 2020 Eduardo Chappa
+ * Copyright 2019-2022 Eduardo Chappa
  * Copyright 2008-2011 Mark Crispin
  * ========================================================================
  */
@@ -2058,6 +2058,7 @@ long nntp_send_auth_work (SENDSTREAM *stream,NETMBX *mb,char *pwd,long flags)
       sprintf (tmp,"Retrying using %s authentication after %.80s",
 	       at->name,lsterr);
       mm_log (tmp,NIL);
+      delete_password(mb, mb ? mb->user : NULL);
       fs_give ((void **) &lsterr);
     }
     trial = 0;			/* initial trial count */
@@ -2066,6 +2067,7 @@ long nntp_send_auth_work (SENDSTREAM *stream,NETMBX *mb,char *pwd,long flags)
       if (lsterr) {
 	sprintf (tmp,"Retrying %s authentication after %.80s",at->name,lsterr);
 	mm_log (tmp,WARN);
+	delete_password(mb, mb ? mb->user : NULL);
 	fs_give ((void **) &lsterr);
       }
       stream->saslcancel = NIL;
@@ -2096,6 +2098,8 @@ long nntp_send_auth_work (SENDSTREAM *stream,NETMBX *mb,char *pwd,long flags)
       sprintf (tmp,"Can not authenticate to NNTP server: %.80s",lsterr);
       mm_log (tmp,ERROR);
     }
+    if(!ret && stream->netstream)
+       delete_password(mb, mb ? mb->user : NULL);
     fs_give ((void **) &lsterr);
   }
   else if (mb->secflag)		/* no SASL, can't do /secure */
@@ -2124,6 +2128,8 @@ long nntp_send_auth_work (SENDSTREAM *stream,NETMBX *mb,char *pwd,long flags)
       stream->sensitive = T;	/* hide this command */
       if (nntp_send_work (stream,"AUTHINFO PASS",pwd2) == NNTPAUTHED)
 	ret = LONGT;		/* password OK */
+      else
+        delete_password(mb, mb ? mb->user : NULL);
       stream->sensitive = NIL;	/* unhide */
       if (ret) break;		/* OK if successful */
     default:			/* authentication failed */
