@@ -1,5 +1,5 @@
 /* ========================================================================
- * Copyright 2015-2020 Eduardo Chappa
+ * Copyright 2015-2022 Eduardo Chappa
  * Copyright 2008 Mark Crispin
  * ========================================================================
  */
@@ -281,7 +281,7 @@ SENDSTREAM *smtp_open_full (NETDRIVER *dv,char **hostlist,char *service,
 
 long smtp_auth (SENDSTREAM *stream,NETMBX *mb,char *tmp)
 {
-  unsigned long trial,auths, authsaved;
+  unsigned long trial,auths, authsaved = NIL;
   char *lsterr = NIL;
   char usr[MAILTMPLEN], *base;
   AUTHENTICATOR *at, *atsaved;
@@ -301,6 +301,7 @@ long smtp_auth (SENDSTREAM *stream,NETMBX *mb,char *tmp)
       sprintf (tmp,"Retrying using %s authentication after %.80s",
 	       at->name,lsterr);
       mm_log (tmp,NIL);
+      delete_password(mb, usr);
       fs_give ((void **) &lsterr);
     }
     trial = 0;			/* initial trial count */
@@ -310,6 +311,7 @@ long smtp_auth (SENDSTREAM *stream,NETMBX *mb,char *tmp)
 	sprintf (tmp,"Retrying %s authentication after %.80s",at->name,lsterr);
 	mm_log (tmp,WARN);
 	fs_give ((void **) &lsterr);
+	delete_password(mb, usr);
       }
       if(at->flags & AU_SINGLE){
 	sprintf(tmp, "AUTH %s", at->name);
@@ -343,6 +345,8 @@ long smtp_auth (SENDSTREAM *stream,NETMBX *mb,char *tmp)
       sprintf (tmp,"Can not authenticate to SMTP server: %.80s",lsterr);
       mm_log (tmp,ERROR);
     }
+    if(!ret && stream->netstream)
+       delete_password(mb, usr);
     fs_give ((void **) &lsterr);
   }
   if(mb && *mb->auth){
