@@ -348,7 +348,7 @@ void mm (MAILSTREAM *stream,long debug)
 	for(i = 0; i < 3; ++i) {
 	  puts(nstypes[i]);
 	  for(ns = nslist[i]; ns; ns = ns->next)
-	    printf(" namespace = %s, delimeter = %c\n", ns->name, ns->delimiter);
+	    printf(" namespace = %s, delimiter = %c\n", ns->name, ns->delimiter);
 	}
       }
       break;
@@ -705,7 +705,7 @@ void mm_dlog (char *string)
 }
 
 
-void mm_login (NETMBX *mb,char *user,char *pwd,long trial)
+void mm_login (NETMBX *mb,char *user,char **pwd,long trial)
 {
   char *s,tmp[MAILTMPLEN];
   if (curhst) fs_give ((void **) &curhst);
@@ -724,9 +724,16 @@ void mm_login (NETMBX *mb,char *user,char *pwd,long trial)
   }
   if (curusr) fs_give ((void **) &curusr);
   curusr = cpystr (user);
-  strcpy (pwd,getpass (s));
+  if(pwd) *pwd = cpystr(getpass (s));
 }
 
+/* IMPLEMENT THIS LATER */
+void mm_login_method (NETMBX *mb,char *user,void *pwd,long trial, char *method)
+{
+  mm_login(mb, user, (char **) pwd, trial);
+}
+
+
 
 void mm_critical (MAILSTREAM *stream)
 {
