@@ -917,8 +917,8 @@ long unix_copy (MAILSTREAM *stream,char *sequence,char *mailbox,long options)
       return NIL;
     }
 
-				/* try to open rewrite for UIDPLUS */
-  if ((tstream = mail_open_work (&unixdriver,NIL,mailbox,
+				/* try to open readwrite for UIDPLUS */
+  if (cu && (tstream = mail_open_work (&unixdriver,NIL,mailbox,
 				 OP_SILENT|OP_NOKOD)) && tstream->rdonly)
     tstream = mail_close (tstream);
   if (cu && !tstream) {		/* wanted a COPYUID? */
