@@ -1,11 +1,7 @@
-#if	!defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: attach.c 1082 2008-06-12 18:39:50Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -435,7 +431,7 @@ SyncAttach(void)
          comment[1024];
     struct hdr_line *lp;			/* current line in header    */
     struct headerentry *entry;
-    PATMT *tp, **knwn = NULL, **bld;
+    PATMT *tp, **knwn = NULL, **bld = NULL;
     EML eml;
 
     if(Pmaster == NULL)
@@ -544,6 +540,8 @@ SyncAttach(void)
 
 		    strncpy(tp->filename, file, j);
 		    tp->filename[j] = '\0';
+
+		    if(tp->id) fs_give((void **) &tp->id);
 		}
 		else if(tp->size && strcmp(tp->size, size)){
 		    rv = 1;
@@ -648,7 +646,7 @@ ParseAttach(struct hdr_line **lp,		/* current header line      */
 	    size_t cmntlen,
 	    int *no)				/* attachment number        */
 {
-    int  j, status, bod, eod = -1,
+    int  j = 0, status, bod, eod = -1,
          rv = 0,				/* return value             */
 	 orig_offset,
          lbln  = 0,				/* label'd attachment	    */
@@ -778,7 +776,7 @@ ParseAttach(struct hdr_line **lp,		/* current header line      */
 		utf8 = ucs4_to_utf8_cpystr(tmp);
 		*no = atoi(utf8);		/* and the old place in list */
 		if(strcmp(number, utf8)){
-		    if(p-tmp > *off){		/* where to begin replacemnt */
+		    if(p-tmp > *off){		/* where to begin replacement */
 			UCS uu[1];
 
 			uu[0] = '\0';
@@ -1116,7 +1114,7 @@ process_tag:					/* enclosed in []         */
 		if(strcmp(sz, (lblsz) ? lblsz : prettysz(attsz))){
 		    strncpy(sz, (lblsz) ? lblsz : prettysz(attsz), szlen);
 		    sz[szlen-1] = '\0';
-		    if(p-tmp > *off){		/* where to begin replacemnt */
+		    if(p-tmp > *off){		/* where to begin replacement */
 			UCS uu[1];
 
 			uu[0] = '\0';
