@@ -1,11 +1,7 @@
-#if	!defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: display.c 1025 2008-04-08 22:59:38Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -375,7 +371,7 @@ int
 window_signature_block(WINDOW *wp)
 {
   LINE *lp, *llp;
-  int in_sig, is_sig_start;
+  int in_sig, is_sig_start = 0;
   int change = 0;
 
   llp = wp->w_linep;
@@ -425,10 +421,12 @@ update(void)
     int     j;
     int     scroll = 0;
     int     repaint= 0;
-    int	    quoted;
     CELL	     c;
     PCOLORS *pcolors = Pmaster && Pmaster->colors ? Pmaster->colors : Pcolors;
 
+    if (sendnow)
+	return;
+
 #if	TYPEAH
     if (typahead())
 	return;
@@ -989,12 +987,12 @@ updext(void)
 void
 updatelinecolor (int row, CELL vline[], CELL pline[], short *flags, int len)
 {
-    CELL *cp1, *cp2, *cp3, *cp4, *cp5, *cp6, *cp7;
+    CELL *cp1, *cp2, *cp3, *cp4, *cp5;
     int   nbflag;		/* non-blanks to the right flag? */
     int   cleartoeol = 0;
-    int   in_quote, quote_found = 0, level;
+    int   in_quote, level;
     PCOLORS *pcolors = Pmaster && Pmaster->colors ? Pmaster->colors : Pcolors;
-    COLOR_PAIR *qcolor = NULL, *lastc = NULL, *pcolor = NULL;
+    COLOR_PAIR *lastc = NULL, *pcolor = NULL;
     int first = 1, lastattr = -1, change = 0;
 
     if(pcolors == NULL){
@@ -1161,7 +1159,7 @@ updateline(int row,			/* row on screen */
     int   nbflag;		/* non-blanks to the right flag? */
     int   cleartoeol = 0;
 
-    if(row < 0 || row > term.t_nrow)
+    if(row < 0 || row > term.t_nrow || sendnow)
       return;
 
     if((Pmaster && Pmaster->colors) || Pcolors){
@@ -1394,7 +1392,7 @@ modeline(WINDOW *wp)
 
 	bp = wp->w_bufp;
 	if(bp->b_fname[0])				/* File name? */
-	  snprintf(t2, sizeof(t2), "File: %s", bp->b_fname);
+	  snprintf(t2, sizeof(t2), "File: %.*s", (int) sizeof(t2) - 7, bp->b_fname);
         else{
 	    strncpy(t2, PICO_NEWBUF_MSG, sizeof(t2));
 	    t2[sizeof(t2)-1] = '\0';
@@ -1431,7 +1429,7 @@ modeline(WINDOW *wp)
 	      w2_to_3 = term.t_ncol - (ALLBUTSPACE + w1_to_2);
 	    else{
 	      if(bp->b_fname[0]){
-	        snprintf(t2, sizeof(t2), "%s", bp->b_fname);
+	        snprintf(t2, sizeof(t2), "%.*s", (int) sizeof(t2) - 1, bp->b_fname);
 	        w2 = utf8_width(t2);
 	      }
 
@@ -1535,7 +1533,7 @@ get_cursor(int *row, int *col)
 void
 mlerase(void)
 {
-    if (term.t_nrow < term.t_mrow)
+    if (term.t_nrow < term.t_mrow || sendnow)
       return;
 
     movecursor(term.t_nrow - term.t_mrow, 0);
@@ -1585,9 +1583,7 @@ speller_choice(char **sp_list, int *choice)
 	ch_dict = -1;
 
     if(ch_dict < 0){		/* not a choice yet? do one now! */
-	UCS buf[128];
 	int i;
-	char *utf8_prompt;
 	UCS  *ucs4_prompt;
 	EXTRAKEYS    menu_dictionary[] = {
 		{"0", NULL, '0'},
@@ -1608,7 +1604,6 @@ speller_choice(char **sp_list, int *choice)
 	if(cnt < 10)
 	  menu_dictionary[cnt].name = NULL;
 
-	buf[0] = '\0';
 	/* write the prompt in utf8, and let internal functions translate it to ucs4 */
 	ucs4_prompt = utf8_to_ucs4_cpystr(_("Choose Dictionary: "));
 
@@ -1638,7 +1633,6 @@ mlchoose(UCS *prompt, EXTRAKEYS *extras)
     UCS      c;
     UCS      buf[NLINE];
     int      i;
-    int      changed = FALSE;
     int      return_val = 0;
     KEYMENU  menu_choose[12];
     COLOR_PAIR *lastc = NULL;
@@ -1806,6 +1800,10 @@ mlyesno(UCS *prompt, int dflt)
     menu_yesno[6].label = N_("Cancel");
     menu_yesno[7].name  = "N";
     menu_yesno[7].label = (dflt == FALSE) ? "[" N_("No") "]" : N_("No");
+    if(Pmaster && Pmaster->onctrlc){
+      menu_yesno[8].name  = "T";
+      menu_yesno[8].label = N_("counT");
+    }
     wkeyhelp(menu_yesno);		/* paint generic menu */
     sgarbk = TRUE;			/* mark menu dirty */
     if(Pmaster && curwp)
@@ -1883,6 +1881,14 @@ mlyesno(UCS *prompt, int dflt)
 		km_popped++;
 		break;
 	    }
+
+	  case 'T':
+	  case 't':
+	    if(Pmaster && Pmaster->onctrlc){
+	      pputs_utf8(_("counT"), 1);
+	      rv = COUNT;
+	      break;
+	    }
 	    /* else fall through */
 
 	  default:
@@ -2196,6 +2202,11 @@ mlreplyd(UCS *prompt, UCS *buf, int nbuf, int flg, EXTRAKEYS *extras)
 	    b = &buf[ucs4_strlen(buf)];
 	    continue;
 
+          case (CTRL|'\\'):
+           if ((c = GetAccent()))
+             goto text;
+          continue;
+
 	  case (CTRL|'F') :			/* CTRL-F forward a char*/
 	  case KEY_RIGHT :
 	    if(*b == '\0')
@@ -2205,6 +2216,18 @@ mlreplyd(UCS *prompt, UCS *buf, int nbuf, int flg, EXTRAKEYS *extras)
 
 	    continue;
 
+	  case (CTRL|'N'):			/* Insert pattern */
+	   if (pat[0] != '\0'){
+		ucs4_strncpy(buf+ucs4_strlen(buf), pat, NPAT);
+		pputs(pat,1);
+		b = &buf[ucs4_strlen(buf)];
+		dline.vused += ucs4_strlen(pat);
+		changed = TRUE;
+		}
+	   else
+		(*term.t_beep)();
+	  continue;
+
 	  case (CTRL|'G') :			/* CTRL-G help		*/
 	    if(term.t_mrow == 0 && km_popped == 0){
 		movecursor(term.t_nrow-2, 0);
@@ -2314,7 +2337,7 @@ mlreplyd(UCS *prompt, UCS *buf, int nbuf, int flg, EXTRAKEYS *extras)
 #endif
 
 	  default : 
-
+text:
 	    /* look for match in extra_v */
 	    for(i = 0; i < 12; i++)
 	      if(c && c == extra_v[i]){
@@ -2416,7 +2439,7 @@ emlwrite_ucs4(UCS *message, EML *eml)
 
     mlerase();
 
-    if(!(message && *message) || term.t_nrow < 2)	
+    if(!(message && *message) || term.t_nrow < 2 || sendnow)	
       return;    /* nothing to write or no space to write, bag it */
 
     bufp = message;
@@ -2606,8 +2629,9 @@ mlwrite(UCS *fmt, void *arg)
     }
 
     ret = ttcol;
-    while(ttcol < term.t_ncol)
-      pputc(' ', 0);
+    if(sendnow == 0)
+      while(ttcol < term.t_ncol)
+        pputc(' ', 0);
 
     movecursor(term.t_nrow - term.t_mrow, ret);
 
@@ -3086,6 +3110,8 @@ pputc(UCS c,				/* char to write */
 {
     int ind, width, printable_ascii = 0;
 
+    if(sendnow)
+	return;
     /*
      * This is necessary but not sufficient to allow us to draw. Note that
      * ttrow runs from 0 to t_nrow (so total number of rows is t_nrow+1)
@@ -3140,6 +3166,8 @@ void
 pputs(UCS *s,				/* string to write */
       int a)				/* and its attribute */
 {
+    if(sendnow)
+	return;
     while (*s != '\0')
       pputc(*s++, a);
 }
@@ -3150,6 +3178,8 @@ pputs_utf8(char *s, int a)
 {
     UCS *ucsstr = NULL;
 
+    if(sendnow)
+	return;
     if(s && *s){
 	ucsstr = utf8_to_ucs4_cpystr(s);
 	if(ucsstr){
@@ -3459,6 +3489,9 @@ wkeyhelp(KEYMENU *keymenu)
     char  nbuf[NLINE];
 #endif
 
+    if(sendnow)
+	return;
+
 #ifdef _WINDOWS
     pico_config_menu_items (keymenu);
 #endif
