@@ -32,6 +32,7 @@
 
 /* initialized global definitions */
 PCOLORS  *Pcolors = NULL;		/* colors for Pico		*/
+int	sendnow = 0;			/* should we send now           */
 int	direction = 0;			/* direction of writing		*/
 int     fillcol = 72;                   /* Current fill column          */
 int     userfillcol = -1;               /* Fillcol set from cmd line    */
@@ -90,6 +91,7 @@ void    *input_cs;		/* passed to mbtow() via kbseq() */
 /* initialized global external declarations */
 
 extern  PCOLORS *Pcolors;		/* colors for Pico		*/
+extern	int	sendnow;		/* should we send now           */
 extern  int	direction;
 extern  int     fillcol;                /* Fill column                  */
 extern  int     userfillcol;            /* Fillcol set from cmd line    */
