@@ -1,7 +1,3 @@
-#if	!defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: fileio.c 769 2007-10-24 00:15:40Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006 University of Washington
@@ -73,7 +69,7 @@ ffputline(CELL buf[], int nbuf)
 
     if(ferror(g_pico_fio.fp)){
 	eml.s = errstr(errno);
-        emlwrite("\007Write error: %s", &eml);
+        emlwwrite(_("Write error: %s"), &eml);
 	sleep(5);
         return FIOERR;
     }
