@@ -1,11 +1,7 @@
-#if	!defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: main.c 1184 2008-12-16 23:52:15Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -427,7 +423,7 @@ main(int argc, char *argv[])
 
 #ifdef	MOUSE
 #ifdef  EX_MOUSE
-	/* New mouse function for real mouse text seletion. */
+	/* New mouse function for real mouse text selection. */
 	register_mfunc(mouse_in_pico, 2, 0, term.t_nrow - (term.t_mrow + 1),
 		       term.t_ncol);
 #else
@@ -495,10 +491,9 @@ void
 display_color_codes(void)
 {
 #define SPACES "   "
-  int i, j, k, l, a, len, len_entry, row;
+  int i, k, l, a;
   int ncolors;
   COLOR_PAIR *lastc = NULL, *newcp;
-  char *fg;
 
   /* this is the format "SPACE COLORED_SPACES = CODE SPACE" */
   vtterminalinfo(gmode & MDTCAPWINS);
@@ -1093,7 +1088,7 @@ pico_set_global_colors(int nc, int ntfg, int ntbg, int rtfg, int rtbg,
   memset((void *)pcolors, 0, sizeof(PCOLORS));
   /* ignore bad pair settings, also we set tbcp backwards because it will
    * be reversed later in the modeline function, so tbcp->fg is actually 
-   * tbcp->bg and viceversa.
+   * tbcp->bg and vice versa.
    */
   if(ntfg >= 0 && ntbg >= 0){	/* set normal text color */
         fg = colorx(ntfg); bg = colorx(ntbg);
