@@ -1,11 +1,7 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: color.c 769 2007-10-24 00:15:40Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -527,7 +523,7 @@ init_color_table(void)
 {
     struct color_table *ct = NULL, *t;
     int                 i, count;
-    char                colorname[12];
+    char                colorname[22];
 
     count = pico_count_in_color_table();
 
@@ -1680,7 +1676,7 @@ color_to_asciirgb(char *colorName)
 	 * but at least the embedded colors in filter.c will get properly
 	 * sucked up when they're encountered.
 	 */
-	strncpy(c_to_a_buf[whichbuf], "xxxxxxxxxxx", RGBLEN);  /* RGBLEN is 11 */
+	strcpy(c_to_a_buf[whichbuf], "xxxxxxxxxxx");
 	l = strlen(colorName);
 	strncpy(c_to_a_buf[whichbuf], colorName, (l < RGBLEN) ? l : RGBLEN);
 	c_to_a_buf[whichbuf][RGBLEN] = '\0';
