@@ -1,11 +1,7 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: filesys.c 770 2007-10-24 00:23:09Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2021 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -321,8 +317,18 @@ getfnames(char *dn, char *pat, int *n, char *e, size_t elen)
 	/*
 	 * We'd like to use 512 * st_blocks as an initial estimate but
 	 * some systems have a stat struct with no st_blocks in it.
+	 *
+	 * In some systems the size of a directory is the sum of the
+	 * sizes of all files contained in it, so sbuf.st_size might
+	 * be too large and the malloc() might fail with error ENOMEM.
+	 * Since this is just the list of files, and not the contents
+	 * of the files, let us start with a small amount and resize
+	 * when necessary. Reported by Sebasting Knust. Of course the
+	 * correct solution is to read the directory twice, but keeping
+	 * realloc()ing as needed also solves the problem in a less
+	 * elegant way.
 	 */
-	avail = alloced = MAX(sbuf.st_size, incr);
+	avail = alloced = 4096;
 	if((sbuf.st_mode&S_IFMT) != S_IFDIR){
 	    if(e)
 	      snprintf(e, elen, _("Not a directory: \"%s\""), dn);
