@@ -1,11 +1,7 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: signals.c 769 2007-10-24 00:15:40Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -103,7 +99,7 @@ do_hup_signal(int sig)
 RETSIGTYPE
 winch_handler(int sig)
 {
-    int i;
+    int i = 0;
     signal(SIGWINCH, winch_handler);
     if(wheadp != NULL)
       ttresize();
