@@ -1,11 +1,7 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: terminal.c 921 2008-01-31 02:09:25Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -71,6 +67,7 @@ static int      tinfoeeol(void);
 static int      tinfoeeop(void);
 static int      tinfobeep(void);
 static int      tinforev(int);
+static int      tinfoeri(void);
 static int      tinfoopen(void);
 static int      tinfoterminalinfo(int);
 static int      tinfoclose(void);
@@ -111,7 +108,7 @@ char	*_clearscreen, *_moveto, *_up, *_down, *_right, *_left,
 	*_termcap_init,		/* string to start termcap */
         *_termcap_end,		/* string to end termcap */
 	*_op, *_oc, *_setaf, *_setab, *_setf, *_setb, *_scp;
-int	_colors, _pairs, _bce;
+int	_colors, _pairs, _bce, _xhp;
 char     term_name[40];
 
 TERM term = {
@@ -129,7 +126,8 @@ TERM term = {
         tinfoeeol,
         tinfoeeop,
         tinfobeep,
-        tinforev
+        tinforev,
+	tinfoeri
 };
 
 
@@ -387,6 +385,7 @@ tinfoterminalinfo(int termcap_wins)
     _op			= tigetstr("op");
     _oc			= tigetstr("oc");
     _bce		= tigetflag("bce");
+    _xhp		= tigetflag("xhp");
 
     _tlines = tigetnum("lines");
     if(_tlines == -1){
@@ -801,6 +800,16 @@ tinforev(int state)		/* change reverse video status */
 }
 
 
+static int
+tinfoeri(void)
+{
+    if(_xhp && _clearinverse)
+      putpad(_clearinverse);
+
+    return(1);
+}
+
+
 static int
 tinfobeep(void)
 {
@@ -830,6 +839,7 @@ static int      tcapeeol(void);
 static int      tcapeeop(void);
 static int      tcapbeep(void);
 static int      tcaprev(int);
+static int      tcaperi(void);
 static int      tcapopen(void);
 static int      tcapterminalinfo(int);
 static int      tcapclose(void);
@@ -868,7 +878,7 @@ char	*_clearscreen, *_moveto, *_up, *_down, *_right, *_left,
 	*_termcap_init,		/* string to start termcap */
         *_termcap_end,		/* string to end termcap */
 	*_op, *_oc, *_setaf, *_setab, *_setf, *_setb, *_scp;
-int	_colors, _pairs, _bce;
+int	_colors, _pairs, _bce, _xhp;
 char     term_name[40];
 
 TERM term = {
@@ -886,7 +896,8 @@ TERM term = {
         tcapeeol,
         tcapeeop,
         tcapbeep,
-        tcaprev
+        tcaprev,
+	tcaperi
 };
 
 
@@ -1154,6 +1165,7 @@ tcapterminalinfo(int termcap_wins)
     _op			= tgetstr("op", &p);
     _oc			= tgetstr("oc", &p);
     _bce		= tgetflag("ut");
+    _xhp		= tgetflag("xs");
 
     if (p >= &tcapbuf[TCAPSLEN]){
 	puts("Terminal description too big!\n");
@@ -1565,6 +1577,16 @@ tcapeeop(void)
 }
 
 
+static int
+tcaperi(void)
+{
+    if(_xhp && _clearinverse)
+      putpad(_clearinverse);
+
+    return(1);
+}
+
+
 static int
 tcaprev(int state)		/* change reverse video status */
 {				/* FALSE = normal video, TRUE = reverse video */
