@@ -1,11 +1,7 @@
-#if	!defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: pico.c 921 2008-01-31 02:09:25Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -172,6 +168,15 @@ pico(PICO *pm)
     pico_all_done = 0;
     km_popped     = 0;
 
+    if (pm->auto_cmds){
+       int i;
+#define CTRL_X 24
+      for (i = 0;  pm->auto_cmds[i]; i++);
+      if ((i > 1) && (pm->auto_cmds[i - 2] == CTRL_X) && 
+		((pm->auto_cmds[i - 1] == 'y') || (pm->auto_cmds[i-1] == 'Y')))
+      sendnow++;
+    }
+
     if(!vtinit())			/* Init Displays.      */
       return(COMP_CANCEL);
 
@@ -359,7 +364,7 @@ pico(PICO *pm)
 
 #ifdef	MOUSE
 #ifdef  EX_MOUSE
-	/* New mouse function for real mouse text seletion. */
+	/* New mouse function for real mouse text selection. */
 	register_mfunc(mouse_in_pico, 2, 0, term.t_nrow - (term.t_mrow+1),
 		       term.t_ncol);
 #else
@@ -674,12 +679,19 @@ abort_composer(int f, int n)
     result = "";
 
     Pmaster->arm_winch_cleanup++;
+    Pmaster->onctrlc++;
     if(Pmaster->canceltest){
         if(((Pmaster->pine_flags & MDHDRONLY) && !any_header_changes())
 	  || (result = (*Pmaster->canceltest)(redraw_pico_for_callback))){
-	    pico_all_done = COMP_CANCEL;
 	    emlwrite(result, NULL);
 	    Pmaster->arm_winch_cleanup--;
+	    if(Pmaster->curpos[0]){
+	       curwp->w_flag |= WFMODE;		/* and modeline so we  */
+	       sgarbk = TRUE;			/* redraw the keymenu  */
+	       pclear(term.t_nrow - 1, term.t_nrow + 1);
+	       return(FALSE);
+	    }
+	    pico_all_done = COMP_CANCEL;
 	    return(TRUE);
 	}
 	else{
@@ -708,6 +720,12 @@ abort_composer(int f, int n)
 	emlwwrite(_("Cancel Cancelled"), NULL);
 	break;
 
+      case COUNT:
+	showcpos(1,0);
+	emlwrite(Pmaster->curpos, NULL);
+	Pmaster->onctrlc--;
+	break;
+
       default:
 	mlerase();
     }
@@ -750,6 +768,19 @@ wquit(int f, int n)
 	    return(FALSE);
 	}
 
+ 	/* When we send a message using the command line we are going to
+ 	   ignore if the user wants to spell check, we assume he already
+ 	   did */
+ 	if (sendnow){
+ 	    ret = (*Pmaster->exittest)(Pmaster->headents,
+					redraw_pico_for_callback, 
+					Pmaster->allow_flowed_text,
+					&result);
+ 	    if (!ret)
+ 		pico_all_done = COMP_EXIT;
+ 	    return(result ? FALSE : TRUE);
+ 	}
+
 #ifdef	SPELLER
 	if(Pmaster->always_spell_check)
 	  if(spell(0, 0) == -1)
