@@ -3,7 +3,7 @@
  *
  * ========================================================================
  * Copyright 2006-2009 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -209,11 +209,13 @@ typedef struct pico_struct {
     PCOLORS *colors;                    /* colors for titlebar and keymenu */
     void  *input_cs;			/* passed to mbtow() via kbseq() */
     long   pine_flags;			/* entry mode flags */
+    char  curpos[80];			/* where are we now? */
     /* The next few bits are features that don't fit in pine_flags      */
     /* If we had this to do over, it would probably be one giant bitmap */
     unsigned always_spell_check:1;      /* always spell-checking upon quit */
     unsigned strip_ws_before_send:1;    /* don't default strip bc of flowed */
     unsigned allow_flowed_text:1;    /* clean text when done to keep flowed */
+    unsigned onctrlc;			/* are we on ctrl-c command? */
     int   (*helper)();			/* Pine's help function  */
     int   (*showmsg)();			/* Pine's display_message */
     UCS   (*suspend)();			/* Pine's suspend */
@@ -232,6 +234,7 @@ typedef struct pico_struct {
     void  (*winch_cleanup)();		/* callback handling screen resize */
     void  (*newthread)();		/* callback to create new thread   */
     int    arm_winch_cleanup;		/* do the winch_cleanup if resized */
+    int   *auto_cmds;			/* Initial keystroke commands */
     HELP_T search_help;
     HELP_T ins_help;
     HELP_T ins_m_help;
