@@ -4,7 +4,7 @@
 
 /*
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -66,6 +66,7 @@ UCS           *ucs4_particular_width(UCS*, int);
 UCS           *utf8_to_ucs4_cpystr(char *);
 char          *ucs4_to_utf8_cpystr(UCS *);
 char          *ucs4_to_utf8_cpystr_n(UCS *, int);
+char	      *ucs4_to_utf8_n_cpystr(UCS *, int);
 #ifdef _WINDOWS
 LPTSTR         utf8_to_lptstr(LPSTR);
 LPSTR          lptstr_to_utf8(LPTSTR);
@@ -81,6 +82,7 @@ UCS           *ucs4_strncat(UCS *ucs4dst, UCS *ucs4src, size_t n);
 UCS           *ucs4_strchr(UCS *s, UCS c);
 UCS           *ucs4_strrchr(UCS *s, UCS c);
 unsigned       utf8_width(char *);
+unsigned       utf8_widthis(char *);
 size_t         utf8_to_width_rhs(char *, char *, size_t, unsigned);
 int            utf8_snprintf(char *, size_t, char *, ...);
 size_t         utf8_to_width(char *, char *, size_t, unsigned, unsigned *);
