@@ -1,10 +1,6 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: charset.c 1032 2008-04-11 00:30:04Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -846,7 +842,7 @@ conversion_table(char *from_cs, char *to_cs)
 		p = ct->table = (unsigned char *)
 		  fs_get(256 * sizeof(unsigned char));
 		for(i = 0; i < 256; i++){
-		    unsigned int fc;
+		    unsigned int fc = 0;
 		    p[i] = '?';
 		    switch(from->type){	/* get "from" UCS-2 codepoint */
 		    case CT_1BYTE0:	/* ISO 8859-1 */
