@@ -2,7 +2,7 @@
  * $Id: filttype.h 767 2007-10-24 00:03:59Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2013-2021 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -36,6 +36,8 @@ typedef struct filter_s {	/* type to hold data for filter function */
     unsigned char t;		/* temporary char                        */
     char     *line;		/* place for temporary storage           */
     char     *linep;		/* pointer into storage space            */
+    char     *oldline;		/* the previous line to "line"		 */
+    char     *oldlinep;		/* the previous line to "line"		 */
     void     *opt;		/* optional per instance data		 */
     void     *data;		/* misc internal data pointer		 */
     unsigned char queue[1 + GF_MAXBUF];
