@@ -1,6 +1,7 @@
 #include "../pith/headers.h"
 #include "../pith/mailpart.h"
 #include "../pith/store.h"
+#include "../pith/string.h"
 #include "../pith/ical.h"
 
 typedef struct ical_iana_comp_s {
@@ -459,7 +460,6 @@ void
 ical_free_vtimezone(void **vtzpv)
 {
   VTIMEZONE_S **vtzp = (VTIMEZONE_S **) vtzpv;
-  TZ_comp i,j;
 
   if(vtzp == NULL || *vtzp == NULL) return;
 
@@ -487,7 +487,6 @@ void
 ical_free_valarm(void **valarmpv)
 {
   VALARM_S **valarmp = (VALARM_S **) valarmpv;
-  int i, j;
 
   if(valarmp == NULL || *valarmp == NULL) return;
 
@@ -1679,7 +1678,7 @@ ical_non_ascii_valid(unsigned char c)
   static unsigned char icu[6];
   static int utf8_len = 0;
   static int utf8_type = 0;
-  int rv;
+  int rv = 0;
 
   if(utf8_len == 0)
     utf8_type = (c >= 0xF0 && c <= 0xF4) 
@@ -1819,9 +1818,9 @@ ical_parse_duration(char *value, ICAL_DURATION_S *ic_d)
 }
 
 /* return -1 if any error,
-           0 if value has the DATE-TIME form
-           1 if value has the DATE form only
-	   2 if value has the DATE-TIME form and is in GMT.
+           ICAL_DATE_TIME if value has the DATE-TIME form
+           ICAL_DATE if value has the DATE form only
+           ICAL_DATE_TIME_GMT if value has the DATE-TIME form and is in GMT.
  */
 int
 ical_parse_date(char *value, struct tm *t)
@@ -1835,32 +1834,32 @@ ical_parse_date(char *value, struct tm *t)
 
    if(value == NULL) return rv;
 
-   rv = 0;	/* assume DATE-TIME format */
+   rv = ICAL_DATE_TIME;	/* assume DATE-TIME format */
    /* a simple check for the format of the string */
    for(i = 0; isdigit(value[i]); i++);
    if (i == 8 && value[i] == '\0')
-       rv = 1;	
+       rv = ICAL_DATE;
    else
       if (i != 8 || value[i++] != 'T') return -1;
-   if(rv == 0) {
+   if(rv == ICAL_DATE_TIME) {
      for(; isdigit(value[i]); i++);
      if(i != 15 || (value[i] != '\0' && (value[i] != 'Z' || value[i+1] != '\0')))
         return -1;
      if(i == 15 && value[i] == 'Z')
-	rv = 2;
+	rv = ICAL_DATE_TIME_GMT;
    }
 
    Tm.tm_year = ical_get_number_value(value, 0, 4) - 1900;
    Tm.tm_mon  = ical_get_number_value(value, 4, 6) - 1;
    Tm.tm_mday = ical_get_number_value(value, 6, 8);
-   if(rv != 1){
+   if(rv != ICAL_DATE){
      Tm.tm_hour = ical_get_number_value(value, 9, 11);
      Tm.tm_min  = ical_get_number_value(value, 11, 13);
      Tm.tm_sec  = ical_get_number_value(value, 13, 15);
-     Tm.tm_isdst = ICAL_DST_UNKNOWN;
+     Tm.tm_isdst = rv | ICAL_DST_UNKNOWN;
    }
    else
-     Tm.tm_isdst = -1;
+     Tm.tm_isdst = rv;
    *t = Tm;
 
    return (t->tm_mon > 11 || t->tm_mon < 0 
@@ -1878,7 +1877,6 @@ ical_set_date(ICLINE_S *icl, VTIMEZONE_S *vtz)
    ICAL_PARAMETER_S *param;
    char *tz = NULL;
    struct tm ic_date;
-   time_t t;
 
    if(icl == NULL) return;
 
@@ -2183,10 +2181,15 @@ ical_vevent_summary(VCALENDAR_S *vcal)
   VEVENT_S *vevent;
   GEN_ICLINE_S *gicl;
   ICLINE_S *icl;
-  char *k;
+  static int offset = 1000000;	/* impossible value */
+  static int dst;
+  time_t ourtime;
 
   if(vcal == NULL) return NULL;
 
+  if(offset == 1000000)
+    offset = timezone_offset_to_gmt(&dst);
+
   method = vcal->method;
 
   vevent = (VEVENT_S *) vcal->comp[VEvent]; 
@@ -2255,18 +2258,27 @@ ical_vevent_summary(VCALENDAR_S *vcal)
 	int icd;	/* ical date return value */
 
 	memset((void *)&ic_date, 0, sizeof(struct tm));
-	icd = ical_parse_date(icl->value, &ic_date);
+	icd = ical_parse_date(icl->value, &ic_date) & 0x00fff;
 	tzid = ical_get_tzid(icl->param);
 	if(icd >= 0){
 	  ic_date.tm_wday = ical_day_of_week(ic_date);
+	  if(ic_date.tm_isdst & ICAL_DATE_TIME_GMT){	/* GMT time */
+	     ic_date.tm_isdst = dst;
+	     ourtime = mktime(&ic_date);
+	     if(ourtime != (time_t) -1){
+		ourtime += offset;
+		ic_date = *localtime(&ourtime);
+	     }
+	  }
+	  ic_date.tm_isdst = dst;
 	  switch(icd){
-	    case 0: /* DATE-TIME */
+	    case ICAL_DATE_TIME: /* DATE-TIME */
 		    ical_date_time(tmp, sizeof(tmp), &ic_date);
 		    break;
-	    case 1: /* DATE */
+	    case ICAL_DATE: /* DATE */
 		    our_strftime(tmp, sizeof(tmp), "%a %x", &ic_date);
 		    break;
-	    case 2: /* DATE-TIME in GMT, Bug: add adjust to time zone */
+	    case ICAL_DATE_TIME_GMT: /* DATE-TIME in GMT */
 		    our_strftime(tmp, sizeof(tmp), "%a %x %I:%M %p", &ic_date);
 		    break;
 	    default: alpine_panic("Unhandled ical date format");
@@ -2343,23 +2355,32 @@ ical_vevent_summary(VCALENDAR_S *vcal)
 	      int icd;
 
 	      memset((void *)&ic_date, 0, sizeof(struct tm));
-	      icd = ical_parse_date(icl->value, &ic_date);
+	      icd = ical_parse_date(icl->value, &ic_date) & 0x00fff;
 	      tzid = ical_get_tzid(icl->param);
 	      if(icd >= 0){
 	         ic_date.tm_wday = ical_day_of_week(ic_date);
-		 switch(icd){
-		    case 0: /* DATE-TIME */
+		 if(ic_date.tm_isdst & ICAL_DATE_TIME_GMT){	/* GMT time */
+		    ic_date.tm_isdst = dst;
+		    ourtime = mktime(&ic_date);
+		    if(ourtime != (time_t) -1){
+		       ourtime += offset;
+		       ic_date = *localtime(&ourtime);
+		    }
+	         }
+	         ic_date.tm_isdst = dst;
+	         switch(icd){
+		    case ICAL_DATE_TIME: /* DATE-TIME */
 			    ical_date_time(tmp, sizeof(tmp), &ic_date);
 			    break;
-		    case 1: /* DATE */
+		    case ICAL_DATE: /* DATE */
 			    our_strftime(tmp, sizeof(tmp), "%a %x", &ic_date);
 			    break;
-		    case 2: /* DATE-TIME in GMT, Bug: add adjust to time zone */
+		    case ICAL_DATE_TIME_GMT: /* DATE-TIME in GMT */
 			    our_strftime(tmp, sizeof(tmp), "%a %x %I:%M %p", &ic_date);
 			    break;
 		    default: alpine_panic("Unhandled ical date format");
 			    break;
-	 	}
+	         }
      	  }
 	  else{
 	     strncpy(tmp, _("Error while parsing event date"), sizeof(tmp));
@@ -2391,18 +2412,27 @@ ical_vevent_summary(VCALENDAR_S *vcal)
        int icd;
 
        memset((void *)&ic_date, 0, sizeof(struct tm));
-       icd = ical_parse_date(icl->value, &ic_date);
+       icd = ical_parse_date(icl->value, &ic_date) & 0x00fff;
        tzid = ical_get_tzid(icl->param);
        if(icd >= 0){
          ic_date.tm_wday = ical_day_of_week(ic_date);
+	 if(ic_date.tm_isdst & ICAL_DATE_TIME_GMT){	/* GMT time */
+	    ic_date.tm_isdst = dst;
+	    ourtime = mktime(&ic_date);
+	    if(ourtime != (time_t) -1){
+	       ourtime += offset;
+	       ic_date = *localtime(&ourtime);
+	    }
+	 }
+	 ic_date.tm_isdst = dst;
 	 switch(icd){
-	    case 0: /* DATE-TIME */
+	    case ICAL_DATE_TIME: /* DATE-TIME */
 		    ical_date_time(tmp, sizeof(tmp), &ic_date);
 		    break;
-	    case 1: /* DATE */
+	    case ICAL_DATE: /* DATE */
 		    our_strftime(tmp, sizeof(tmp), "%a %x", &ic_date);
 		    break;
-	    case 2: /* DATE-TIME in GMT, Bug: add adjust to time zone */
+	    case ICAL_DATE_TIME_GMT: /* DATE-TIME in GMT */
 		    our_strftime(tmp, sizeof(tmp), "%a %x %I:%M %p", &ic_date);
 		    break;
 	    default: alpine_panic("Unhandled ical date format");
@@ -2542,13 +2572,13 @@ ical_vevent_summary(VCALENDAR_S *vcal)
 	   }
 	   if(*t == ','){
 		*u = '\0';
-		rv->description[i++] = cpystr(ical_decode(s, vcal->encoding));
+		rv->description[i++] = (unsigned char *) cpystr((char *) ical_decode(s, vcal->encoding));
 		s = u = t+1;
 	   } else
 		*u++ = *t;  
 	}
 	*u = '\0';
-	rv->description[i++] = cpystr(ical_decode(s, vcal->encoding));
+	rv->description[i++] = (unsigned char *) cpystr((char *) ical_decode(s, vcal->encoding));
 	rv->description[i] = NULL;
 	fs_give((void **)&v);
      } /* end of if(description) */
