@@ -1,7 +1,7 @@
 #ifndef ICALTYPE_INCLUDED
 #define ICALTYPE_INCLUDED
 
-/* Due to the line by line processing algorithm, not all informatio
+/* Due to the line by line processing algorithm, not all information
  * is available when process some lines. In particular, when we
  * process anything that has to do with time, we do not know if
  * we are processing a date in daylight savings time or not. We
@@ -12,8 +12,12 @@
  * to a different value, ICAL_DST_SET which means we know the date
  * is DST
  */
-#define ICAL_DST_UNKNOWN  (1)
-#define ICAL_DST_SET 	  (ICAL_DST_UNKNOWN + 1)
+#define ICAL_DATE_TIME     (0x00001)
+#define ICAL_DATE          (0x00010)
+#define ICAL_DATE_TIME_GMT (0x00100)
+#define ICAL_DST_UNKNOWN   (0x01000)
+#define ICAL_DST_SET       (0x10000)
+
 
 /* this is the PARAMETER struct from mail.h, but with possibility of
  * extension */
