@@ -2,7 +2,7 @@
  * $Id: imap.h 1074 2008-06-04 00:08:43Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -131,6 +131,8 @@ int	imap_get_passwd_auth (MMLOGIN_S *, char **, char *, STRLIST_S *, int, char *
 void    imap_set_passwd(MMLOGIN_S **, char *, char *, STRLIST_S *, int, int, int);
 void    imap_set_passwd_auth(MMLOGIN_S **, char *, char *, STRLIST_S *, int, int, int, char *);
 void    imap_flush_passwd_cache(int);
+void	imap_delete_passwd_auth (MMLOGIN_S **, char *, STRLIST_S *, int, char *);
+void	imap_delete_passwd (MMLOGIN_S **, char *, STRLIST_S *, int);
 
 
 /* currently mandatory to implement stubs */
