@@ -1,10 +1,6 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: ldap.c 1204 2009-02-02 19:54:23Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -654,13 +650,14 @@ try_password_again:
 	  if(!tlsmustbail){
 	      snprintf(pmt, sizeof(pmt), "  %s", (info->nick && *info->nick) ? info->nick : serv);
 	      mm_login_work(&mb, user, &pwd, pwdtrial, pmt, info->binddn);
-	      if(pwd && pwd[0])
+	      if(pwd && pwd[0]){
 #ifdef _WINDOWS
 		passwd = pwd;
 #else
 		passwd.bv_len = strlen(pwd);
 		passwd.bv_val = pwd;		
 #endif
+	      }
 	  }
       }
 
@@ -709,7 +706,7 @@ try_password_again:
 	dprint((2, "%s\n", ebuf));
       }
       else if(!ps_global->intr_pending){
-	int          srch_res, args, slen, flen;
+	int          srch_res = LDAP_SUCCESS, args, slen, flen;
 #define TEMPLATELEN 512
 	char         filt_template[TEMPLATELEN + 1];
 	char         filt_format[2*TEMPLATELEN + 1];
@@ -1906,26 +1903,32 @@ static struct tl_table ldap_trans_table[]={
     {"officePhone",			N_("Office Telephone")},
     {"facsimileTelephoneNumber",	N_("FAX Telephone")},
     {"mobile",				N_("Mobile Telephone")},
+    {"voiceMailTelephoneNumber",	N_("Voice Mail")},
     {"pager",				N_("Pager")},
     {"roomNumber",			N_("Room Number")},
     {"uid",				N_("User ID")},
+    {"userCertificate",			N_("User Certificate")},
     {NULL,				NULL}
 };
 
 char *
 ldap_translate(char *a, LDAP_SERV_S *info_used)
 {
+    char *s, *ret_a = a;
     int i;
 
+    if((s = strchr(a, ';')) != NULL)
+	*s = '\0';
+
     if(info_used){
 	if(info_used->mailattr && strucmp(info_used->mailattr, a) == 0)
-	  return(_(ldap_trans_table[LDAP_MAIL_ATTR].translated));
+	    ret_a = _(ldap_trans_table[LDAP_MAIL_ATTR].translated);
 	else if(info_used->snattr && strucmp(info_used->snattr, a) == 0)
-	  return(_(ldap_trans_table[LDAP_SN_ATTR].translated));
+	    ret_a = _(ldap_trans_table[LDAP_SN_ATTR].translated);
 	else if(info_used->gnattr && strucmp(info_used->gnattr, a) == 0)
-	  return(_(ldap_trans_table[LDAP_GN_ATTR].translated));
+	    ret_a = _(ldap_trans_table[LDAP_GN_ATTR].translated);
 	else if(info_used->cnattr && strucmp(info_used->cnattr, a) == 0)
-	  return(_(ldap_trans_table[LDAP_CN_ATTR].translated));
+	    ret_a = _(ldap_trans_table[LDAP_CN_ATTR].translated);
     }
 
     for(i = 0; ldap_trans_table[i].ldap_ese; i++){
@@ -1940,10 +1943,13 @@ ldap_translate(char *a, LDAP_SERV_S *info_used)
 	  }
 
 	if(strucmp(ldap_trans_table[i].ldap_ese, a) == 0)
-	  return(_(ldap_trans_table[i].translated));
+	    ret_a = _(ldap_trans_table[i].translated);
     }
-    
-    return(a);
+
+    if(s)
+	*s = ';';
+
+    return ret_a;
 }
 
 char **
