@@ -1,10 +1,6 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: mailcmd.c 1142 2008-08-13 17:22:21Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
- * Copyright 2013-2021 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006-2007 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -790,12 +786,26 @@ do_broach_folder(char *newfolder, CONTEXT_S *new_context, MAILSTREAM **streamp,
 		     openmode | (open_inbox ? SP_INBOX : 0),
 		     &rflags);
 
+    if(m == NULL
+	&& ps_global->in_xoauth2_auth
+	&& ps_global->preserve_password){
+        ps_global->in_xoauth2_auth = ps_global->user_says_cancel = ps_global->preserve_password = 0;
+        m = context_open((new_context && !open_inbox) ? new_context : NULL,
+		     stream,
+		     open_inbox ? ps_global->VAR_INBOX_PATH : expanded_file,
+		     openmode | (open_inbox ? SP_INBOX : 0),
+		     &rflags);
+    }
+
     /*
      * We aren't in a situation where we want a single cancel to
      * apply to multiple opens.
      */
     ps_global->user_says_cancel = 0;
 
+    /* we are not in authentication mode anymore */
+    ps_global->preserve_password = ps_global->in_xoauth2_auth = 0;
+
     if(streamp)
       *streamp = m;
 
@@ -821,7 +831,7 @@ do_broach_folder(char *newfolder, CONTEXT_S *new_context, MAILSTREAM **streamp,
         dprint((8, "Old folder: \"%s\"\n",
                old_folder == NULL ? "" : old_folder));
         if(old_folder != NULL){
-            if(strcmp(old_folder, ps_global->inbox_name) == 0){
+            if(strucmp(old_folder, ps_global->inbox_name) == 0){
                 ps_global->mail_stream = sp_inbox_stream();
 		ps_global->msgmap      = sp_msgmap(ps_global->mail_stream);
 
