@@ -1,11 +1,7 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: msgno.c 854 2007-12-07 17:44:43Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2020 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -617,8 +613,8 @@ msgno_in_select(MSGNO_S *msgs, long int n)
 int
 msgno_exceptions(MAILSTREAM *stream, long int rawno, char *part, int *bits, int set)
 {
-    PINELT_S **peltp;
-    PARTEX_S **partp;
+    PINELT_S **peltp = NULL;
+    PARTEX_S **partp = NULL;
     MESSAGECACHE *mc;
 
     if(!stream || rawno < 1L || rawno > stream->nmsgs)
