@@ -1,10 +1,6 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: stream.c 1012 2008-03-26 00:44:22Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
- * Copyright 2013-2020 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -249,7 +245,7 @@ pine_mail_open(MAILSTREAM *stream, char *mailbox, long int openflags, long int *
      * mistakes caused by conflicts between the two styles. In particular, we
      * don't want to have a new-style cached stream re-opened because of the
      * old-style caching code. This can happen if a stream is passed in that
-     * is not useable, and then a new stream is opened because the passed in
+     * is not usable, and then a new stream is opened because the passed in
      * stream causes us to bypass the new caching code. Play it safe. If it
      * is an IMAP stream, just close it. This should leave it in the new-style
      * cache anyway, causing no loss. Maybe not if the cache wasn't large
@@ -2295,8 +2291,8 @@ pine_imap_cmd_happened(MAILSTREAM *stream, char *cmd, long int flags)
 	sp_set_last_activity(stream, now);
 	if(!(flags & SC_EXPUNGEDEFERRED))
 	  sp_set_last_expunged_reaper(stream, now);
-
-	if(cmd && !strucmp(cmd, "NOOP")) /* but can interrupt this one */
+		 /* but can interrupt these ones */
+	if(cmd && (!strucmp(cmd, "NOOP") || !strucmp(cmd, "LOGOUT")))
 	  ps_global->can_interrupt = 1;
     }
 }
