@@ -1,10 +1,6 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: string.c 910 2008-01-14 22:28:38Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
- * Copyright 2013-2021 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -20,6 +16,7 @@ static char rcsid[] = "$Id: string.c 910 2008-01-14 22:28:38Z hubert@u.washingto
     string.c
     Misc extra and useful string functions
       - rplstr         replace a substring with another string
+      - collspaces     consecutive spaces are reduced to one space.
       - sqzspaces      Squeeze out the extra blanks in a string
       - sqznewlines    Squeeze out \n and \r.
       - removing_trailing_white_space 
@@ -131,6 +128,31 @@ rplstr(char *os, size_t oslen, int dl, char *is)
     return(x3);
 }
 
+/*----------------------------------------------------------------------
+     collapse blank space
+  ----------------------------------------------------------------------*/
+void
+collspaces(char *string)
+{
+    char *p = string;
+    int only_one_space = 0;
+
+    if(!string)
+      return;
+
+    for(;isspace(*p); p++);
+
+    while((*string = *p++) != '\0')
+      if(!isspace((unsigned char)*string)){
+	only_one_space = 0;
+	string++;
+      }
+      else if(!only_one_space){
+		string++;
+		only_one_space++;
+	   }
+    *string = '\0';
+}
 
 
 /*----------------------------------------------------------------------
@@ -1063,14 +1085,27 @@ static struct {
     {"CDT", 3, -5, 0},			/* Central Daylight */
     {"EST", 3, -5, 0},			/* Eastern Standard */
     {"EDT", 3, -4, 0},			/* Eastern Daylight */
-    {"JST", 3,  9, 0},			/* Japan Standard */
     {"GMT", 3,  0, 0},			/* Universal Time */
     {"UT",  2,  0, 0},			/* Universal Time */
-#ifdef	IST_MEANS_ISREAL
+    {"WET", 3,  0, 0},			/* Western Europe Standard */
+    {"WEST", 4, 1, 0},			/* Western Europe Daylight */
+    {"CET", 3,  1, 0},			/* Central Europe Standard */
+    {"CEST", 4, 2, 0},			/* Central Europe Daylight */
+    {"EET", 3,  2, 0},			/* Eastern Europe Standard */
+    {"EEST", 4, 3, 0},			/* Eastern Europe Daylight */
+    {"FET", 3,  3, 0},			/* Further Eastern Europe Standard */
+    {"MSK", 3,  3, 0},			/* Moscow Standard Time */
+    {"BST", 3,  1, 0},			/* Brittish Summer Time */
+    {"JST", 3,  9, 0},			/* Japan Standard */
+#ifdef	IST_MEANS_ISRAEL
     {"IST", 3,  2, 0},			/* Israel Standard */
 #else
 #ifdef	IST_MEANS_INDIA
     {"IST", 3,  5, 30},			/* India Standard */
+#else
+#ifdef IST_MEANS_IRISH
+    {"IST", 3,  1, 0},			/* Irish Standard */
+#endif
 #endif
 #endif
     {NULL, 0, 0},
@@ -1328,6 +1363,35 @@ convert_date_to_local(char *date)
 }
 
 
+int
+timezone_offset_to_gmt(int *dst)
+{
+   int julian, offset;
+   struct tm *tm;
+   time_t     now;
+
+   offset = 0;
+   /* find difference between gmtime and localtime, from c-client do_date */
+   now = time((time_t *) 0);
+   if(now != (time_t) -1){
+      tm = gmtime(&now);
+      if(tm != NULL){
+	offset = tm->tm_hour * 60 + tm->tm_min;		/* minutes */
+	julian = tm->tm_yday;
+
+	tm = localtime(&now);
+	*dst = tm->tm_isdst;		/* for converting back to our time */
+
+	offset = tm->tm_hour * 60 + tm->tm_min - offset;
+	if((julian = tm->tm_yday - julian) != 0)
+	   offset += ((julian < 0) == (abs(julian) == 1)) ? -24*60 : 24*60;
+
+	offset *= 60;		/* change to seconds */
+      }
+   }
+   return offset;
+}
+
 time_t
 date_to_local_time_t(char *date)
 {
@@ -1337,31 +1401,8 @@ date_to_local_time_t(char *date)
     static int  zone = 1000000;		/* initialize timezone offset */
     static int  dst;
 
-    if(zone == 1000000){
-      int julian;
-      struct tm *tm;
-      time_t     now;
-
-      zone = 0;
-      /* find difference between gmtime and localtime, from c-client do_date */
-      now = time((time_t *) 0);
-      if(now != (time_t) -1){
-	tm = gmtime(&now);
-	if(tm != NULL){
-	  zone = tm->tm_hour * 60 + tm->tm_min;		/* minutes */
-	  julian = tm->tm_yday;
-
-	  tm = localtime(&now);
-	  dst = tm->tm_isdst;		/* for converting back to our time */
-
-	  zone = tm->tm_hour * 60 + tm->tm_min - zone;
-	  if((julian = tm->tm_yday - julian) != 0)
-	    zone += ((julian < 0) == (abs(julian) == 1)) ? -24*60 : 24*60;
-
-	  zone *= 60;		/* change to seconds */
-        }
-      }
-    }
+    if(zone == 1000000)
+      zone = timezone_offset_to_gmt(&dst);
 
     parse_date(date, &d);
 
@@ -2997,3 +3038,64 @@ convert_decimal_to_alpha (char *rn, size_t len, long n, char l)
   if(i < len) rn[i] = '\0';
   rn[len-1] = '\0';
 }
+
+void
+remove_quotes(unsigned char *name)
+{
+  unsigned char *s, *bos, *eos;
+  int startquote, endquote;
+
+  startquote = endquote = 0;
+
+  for(s = name; s && *s; s++){
+     endquote = startquote && (*s == '"') ? 1 : 0;
+     if(endquote)
+	eos = s;
+     if(startquote == 0){
+	if(*s == '"')
+	   startquote = 1;
+	if(startquote)
+	   bos = s;
+     }
+     if(startquote && endquote){
+	if(bos == name && eos[1] == '\0'){
+	   for(s = name + 1; *s && s < eos; s++)
+	      *(s-1) = *s;
+	   *(s-1) = '\0';
+	}
+	startquote = endquote = 0;
+     }
+  }
+}
+
+
+void
+removing_extra_stuff(string)
+    char *string;
+{
+    char *p = NULL;
+    int change = 0, length = 0;
+
+
+    if(!string)
+      return;
+
+    for(; *string; string++, length++)
+      p = ((unsigned char)*string != ',') ? NULL : (!p) ? string : p;
+
+    if(p)
+      *p = '\0';
+
+    string -= length;
+        for (; *string; string++){
+           if (change){
+              *string = ' ';
+              change = 0;
+           }
+           if ((((unsigned char)*string == ' ') ||
+                ((unsigned char)*string == ',')) &&
+                ((unsigned char)*(string + 1) == ','))
+            change++;
+        }
+}
+
