@@ -2,7 +2,7 @@
  * $Id: string.h 769 2007-10-24 00:15:40Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2013-2021 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  * Copyright 2006-2007 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -87,6 +87,7 @@ struct date {
 
 /* exported prototypes */
 char	   *rplstr(char *, size_t, int, char *);
+void	    collspaces(char *);
 void	    sqzspaces(char *);
 void	    sqznewlines(char *);
 void	    removing_leading_white_space(char *);
@@ -94,6 +95,7 @@ void	    removing_trailing_white_space(char *);
 void	    replace_tabs_by_space(char *);
 void	    removing_leading_and_trailing_white_space(char *);
 int 	    removing_double_quotes(char *);
+void	    removing_extra_stuff (char *);
 char	   *skip_white_space(char *);
 char	   *skip_to_white_space(char *);
 char	   *removing_quotes(char *);
@@ -152,5 +154,7 @@ int         read_octal(char **);
 time_t      date_to_local_time_t(char *);
 void	    convert_decimal_to_roman (char *, size_t, long, char);
 void	    convert_decimal_to_alpha (char *, size_t, long, char);
+int	    timezone_offset_to_gmt(int *);
+void	    remove_quotes(unsigned char *);
 
 #endif /* PITH_STRING_INCLUDED */
