@@ -1,11 +1,7 @@
-#if !defined(lint) && !defined(DOS)
-static char rcsid[] = "$Id: takeaddr.c 1012 2008-03-26 00:44:22Z hubert@u.washington.edu $";
-#endif
-
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2021 Eduardo Chappa
+ * Copyright 2013-2022 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -2098,6 +2094,8 @@ fill_in_ta(TA_S **old_current, struct mail_address *addr, int checked, char *pri
 	    new_current->checked  = checked != 0;
 	    new_current->addr     = copyaddr(addr);
 	    decode_addr_names_to_utf8(new_current->addr);
+	    if(new_current->addr && new_current->addr->personal)
+	       remove_quotes(new_current->addr->personal);
 	    if(addr->host[0] == '.')
 	      new_current->strvalue = cpystr("Error in address (ok to try Take anyway)");
 	    else{
